<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DomPlugin</name>
    <message>
        <location filename="../domplugin.cpp" line="41"/>
        <source>Panel DOM Tree</source>
        <translation>Panel DOM ağacı</translation>
    </message>
</context>
<context>
    <name>TreeWindow</name>
    <message>
        <location filename="../treewindow.ui" line="14"/>
        <source>Panel DOM Tree</source>
        <translation>Panel DOM ağacı</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="63"/>
        <location filename="../treewindow.ui" line="96"/>
        <source>Property</source>
        <translation>Özellik</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="68"/>
        <source>Value</source>
        <translation>Değer</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="76"/>
        <source>All properties</source>
        <translation>Tüm özellikler</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="101"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="106"/>
        <source>String value</source>
        <translation>Dizi değeri</translation>
    </message>
</context>
</TS>
